package logo;

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;


/*************************************************************************

	Un petit Logo minimal qui devra tre amlior par la suite

				J. Ferber - 1999-2001

				Cours de DESS TNI - Montpellier II

	@version 2.0
	@date 25/09/2001

**************************************************************************/

/** La classe Tortue qui se dplace en coordonnes polaires
**/

class Tortue
{

	double convDegGrad = 0.0174533; // la constante de conversion de degres en gradient


	FeuilleDessin feuille;	// la feuille de dessin sur laquelle dessine la tortue


	int x, y;	// les coordonnees de la tortue
	int dir;	// la direction de la tortue
	boolean crayon=true; // par defaut on suppose qu'on dessine
	int coul;
	public void setColor(int n){coul = n;}
	public int getColor() {return coul;}

	public Tortue(FeuilleDessin f){
		feuille = f;
		feuille.addTortue(this);
		reset();
	}

	void reset()
  	{	// on initialise la position de la tortue
		x = 250;
		y = 180;
		dir = -90;
		crayon = true;
  	}

	protected static final int rp=10,rb=5;
	protected void drawTurtle (Graphics g){
      //Calcule les 3 coins du triangle a partir de
      // la position de la tortue p
	  Point p = new Point(x,y);
	  Polygon arrow = new Polygon();

      //Calcule des deux bases
      //Angle de la droite
      double theta=convDegGrad*(-dir);
      //Demi angle au sommet du triangle
      double alpha=Math.atan( (float)rb / (float)rp );
      //Rayon de la fleche
      double r=Math.sqrt( rp*rp + rb*rb );
      //Sens de la fleche

      //Pointe
	  Point p2=new Point((int) Math.round(p.x+r*Math.cos(theta)),
						 (int) Math.round(p.y-r*Math.sin(theta)));
	  arrow.addPoint(p2.x,p2.y);
	  arrow.addPoint((int) Math.round( p2.x-r*Math.cos(theta + alpha) ),
		  (int) Math.round( p2.y+r*Math.sin(theta + alpha) ));

      //Base2
	  arrow.addPoint((int) Math.round( p2.x-r*Math.cos(theta - alpha) ),
		  (int) Math.round( p2.y+r*Math.sin(theta - alpha) ));

	  arrow.addPoint(p2.x,p2.y);
	  g.setColor(Color.green);
	  g.fillPolygon(arrow);
    }

  	Color decodeColor(int c) {
  		switch(c) {
  			case 0: return(Color.black);
  			case 1: return(Color.blue);
  			case 2: return(Color.cyan);
  			case 3: return(Color.darkGray);
  			case 4: return(Color.red);
  			case 5: return(Color.green);
  			case 6: return(Color.lightGray);
  			case 7: return(Color.magenta);
  			case 8: return(Color.orange);
  			case 9: return(Color.gray);
  			case 10: return(Color.pink);
  			case 11: return(Color.yellow);
  			default : return(Color.black);
		}
  	}

	/** les procedures de base de fonctionnement de la tortue */

	// avancer de n pas
	void avancer(int dist)
	{	Graphics g = feuille.getImageGraphics();

		int newX = (int) Math.round(x+dist*Math.cos(convDegGrad*dir));
		int newY = (int) Math.round(y+dist*Math.sin(convDegGrad*dir));
		if (crayon) {
			g.setColor(decodeColor(coul));
			g.drawLine(x,y,newX,newY);
		}
		x = newX;
		y = newY;
		//if (getShowTurtle())
		//  this.drawTurtle(g);
		// System.out.println("dir: " + dir);
		feuille.drawIt();
	}

	// aller  droite
	void droite(int ang)
	{
		dir = (dir + ang) % 360;
		feuille.drawIt();
	}

	// aller  gauche
	void gauche(int ang)
	{
		dir = (dir - ang) % 360;
		feuille.drawIt();
	}


	// baisser le crayon pour dessiner
	void baisserCrayon()
	{
		crayon = true;
	}

	// lever le crayon pour ne plus dessiner
	void leverCrayon()
	{
		crayon = false;
	}

	// pour changer de couleur de dessin
	void couleur(int n)
	{
		coul = n % 12;
	}

	void couleurSuivante() {
	 	couleur(coul+1);
	}

	/** quelques classiques */

	void carre() {
		for (int i=0;i<4;i++) {
			avancer(100);
			droite(90);
		}
	}

	void poly(int n, int a) {
		for (int j=0;j<a;j++) {
			avancer(n);
			droite(360/a);
		}
	}

	void spiral(int n, int k, int a) {
		for (int i = 0; i < k; i++) {
			couleur(coul+1);
			avancer(n);
			droite(360/a);
			n = n+1;
		}
	}
}
